#
# spec file for package gdal
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 36
%define sourcename gdal
# Uppercase GDAL is the canonical name for this package in Python
%define pypi_package_name GDAL
%bcond_with ecw_support
%bcond_with ecw5_support
%bcond_with fgdb_support
%bcond_with kml_support
%bcond_with sfcgal_support
%bcond_with hdf4_support
%bcond_with heif_support
%bcond_with qhull_support
%bcond_with deflate_support
%bcond_with tests_support

%if 0%{suse_version} > 1500
%define pythons python3
%else
%{?sle15_python_module_pythons}
%define gccver 13
%endif
%define mypython %pythons
%define __mypython %{expand:%%__%{mypython}}
%define mypython_sitearch %{expand:%%%{mypython}_sitearch}

Name:           gdal
Version:        3.10.3
Release:        1.1
Summary:        GDAL/OGR - a translator library for raster and vector geospatial data formats
License:        BSD-3-Clause AND MIT AND SUSE-Public-Domain
URL:            https://www.gdal.org/
Source0:        https://download.osgeo.org/%{name}/%{version}/%{sourcename}-%{version}.tar.xz
Source1:        https://download.osgeo.org/%{name}/%{version}/%{sourcename}-%{version}.tar.xz.md5
Source2:        https://download.osgeo.org/%{name}/%{version}/%{sourcename}autotest-%{version}.tar.gz
BuildRequires:  KEALib-devel
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  chrpath
BuildRequires:  curl-devel
BuildRequires:  dos2unix
BuildRequires:  doxygen >= 1.4.2
BuildRequires:  fdupes
BuildRequires:  gcc%{?gccver}-c++
BuildRequires:  geos-devel >= 3.8
BuildRequires:  giflib-devel
BuildRequires:  hdf5-devel >= 1.10
BuildRequires:  lapack-devel
BuildRequires:  libcryptopp-devel
BuildRequires:  libdeflate-devel
BuildRequires:  libtool
BuildRequires:  libzstd-devel
BuildRequires:  mysql-devel
# This one is needed for Leap :-(
BuildRequires:  opencl-headers
BuildRequires:  %{mypython}-base
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-numpy-devel
BuildRequires:  %{mypython}-setuptools
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  shapelib >= 1.4
BuildRequires:  swig
BuildRequires:  unixODBC-devel
BuildRequires:  pkgconfig(OpenCL)
# c++17 standard errors for older versions
BuildRequires:  pkgconfig(OpenEXR) >= 3
BuildRequires:  pkgconfig(armadillo)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(expat) >= 1.95.0
BuildRequires:  pkgconfig(freexl)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libgeotiff) >= 1.2.1
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libopenjp2) >= 2.3.1
BuildRequires:  pkgconfig(libpng) >= 1.6
BuildRequires:  pkgconfig(libpq)
BuildRequires:  pkgconfig(libtiff-4) >= 4.1
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwebpdecoder)
BuildRequires:  pkgconfig(libwebpdemux)
BuildRequires:  pkgconfig(libwebpmux)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(poppler) >= 0.86
BuildRequires:  pkgconfig(proj) >= 6.3
BuildRequires:  pkgconfig(shapelib)
BuildRequires:  pkgconfig(spatialite) >= 4.1.2
BuildRequires:  pkgconfig(sqlite3) >= 3.31
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(zlib) >= 1.1.4
%if %{with tests_support}
BuildRequires:  cmake-full
%else
BuildRequires:  cmake
%endif
%if 0%{?sle_version} == 150300 && 0%{?is_opensuse}
BuildRequires:  python-rpm-macros
%endif
%if %{with tests_support}
BuildRequires:  %{mypython}-lxml
BuildRequires:  %{mypython}-pytest
BuildRequires:  %{mypython}-pytest-env
BuildRequires:  %{mypython}-pytest-sugar
BuildRequires:  proj
%endif
%if %{with deflate_support}
BuildRequires:  libdeflate-devel
%endif
%if %{with fgdb_support}
BuildRequires:  filegdb_api-devel
%endif
%if %{with kml_support}
BuildRequires:  pkgconfig(libkml)
%endif
%if %{with sfcgal_support}
BuildRequires:  pkgconfig(sfcgal)
%endif
%if %{with heif_support}
BuildRequires:  libheif-devel
%endif
%if %{with hdf4_support}
BuildRequires:  hdf-devel
%endif
%if %{with qhull_support}
BuildRequires:  pkgconfig(qhull_r)
%endif
%if %{with ecw5_support}
BuildRequires:  ERDAS-ECW_JPEG_2000_SDK-devel
%else
%if %{with ecw_support}
BuildRequires:  libecwj2-devel
%endif
%endif
# 3.9.x we stop requiring this hardly
#Requires:       %%{mypython}-GDAL = %%{version}

%description
GDAL is a translator library for raster geospatial data formats that
is released under an Open Source license. As a library, it presents a
single abstract data model to the calling application for all
supported formats. The related OGR library (which lives within the
GDAL source tree) provides a similar capability for simple features
vector data.

%package devel
Summary:        GDAL library header files
Requires:       lib%{name}%{soversion} = %{version}
Requires:       pkgconfig(libopenjp2)
Provides:       lib%{name}%{soversion}-devel = %{version}
Provides:       lib%{name}-devel = %{version}

%description devel
Development Libraries for the GDAL file format library

%package -n lib%{name}%{soversion}
Summary:        GDAL static libraries
Requires:       lib%{name}-drivers >= %{version}

%description -n lib%{name}%{soversion}
GDAL and OGR are translator libraries for raster and vector geospatial data
formats. As a library, it presents a single abstract data model to the calling
application for all supported formats.

%package -n lib%{name}-drivers
Summary:        GDAL static libraries drivers files
# soversion 32 contained the drivers file and thus will cause a conflict
Conflicts:      lib%{name}32

%description -n lib%{name}-drivers
Drivers information for library

%package -n %{mypython}-%{pypi_package_name}
Summary:        GDAL %{mypython} module
Requires:       %{name} = %{version}-%{release}
Provides:       %{mypython}-%{name} = %{version}
Obsoletes:      %{mypython}-%{name} < %{version}

%description -n %{mypython}-%{pypi_package_name}
The GDAL python modules provide support to handle multiple GIS file formats.

%package bash-completion
Summary:        Bash completion for GDAL
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
bash command line completion support for GDAL

%prep
%autosetup -p1 -n %{sourcename}-%{version} -a2
# Delete bundled libraries
# keep zlib due to missing frmts/zlib/contrib/infback9 in our package
# rm -rv frmts/zlib
rm -rv frmts/png/libpng
rm -rv frmts/gif/giflib
rm -rv frmts/jpeg/libjpeg
rm -rv frmts/jpeg/libjpeg12
rm -rv frmts/gtiff/libgeotiff
rm -rv frmts/gtiff/libtiff
# internal but needed rm -rv frmts/pcidsk

# Fix wrong encoding EOL
for F in frmt_twms_srtm.xml frmt_wms_bluemarble_s3_tms.xml frmt_wms_virtualearth.xml frmt_twms_Clementine.xml;do
  find . -name "${F}" -exec dos2unix {} \;
done

# Remove shebang in scripts located in non executable dir
find swig/python/gdal-utils/osgeo_utils -iname '*.py' -ls -exec sed -i '/^#!\/usr\/bin\/env python3/d' {} \;
find swig/python/gdal-utils/osgeo_utils -iname '*.py' -ls -exec sed -i '/^#!\/usr\/bin\/env python/d' {} \;
# Fix wrong /usr/bin/env python3
find . -iname "*.py" -exec sed -i "s,^#!%{_bindir}/env python3,#!%{__mypython}," {} \;

%build
%{?gccver:export CC=gcc-%{gccver}}
%{?gccver:export CXX=g++-%{gccver}}
%cmake \
  -DGDAL_USE_INTERNAL_LIBS=OFF \
  -DGDAL_USE_EXTERNAL_LIBS=ON \
%if %{with ecw5_support}
  -DECW_ROOT="../ECW/Desktop_Read-Only" \
%endif
  -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/gdal \
  -DGDAL_USE_ARMADILLO=ON \
  -DGDAL_USE_CFITSIO=OFF \
  -DGDAL_USE_CURL=ON \
  -DGDAL_USE_EXPAT=ON \
  -DGDAL_USE_FREEXL=ON \
  -DGDAL_USE_GEOS=ON \
  -DGDAL_USE_GIF=ON \
%if %{with hdf4_support}
  -DGDAL_USE_HDF4=ON \
%else
  -DGDAL_USE_HDF4=OFF \
%endif
  -DGDAL_USE_HDF5=ON \
%if %{with heif_support}
  -DGDAL_USE_HEIF=ON \
%else
  -DGDAL_USE_HEIF=OFF \
%endif
  -DGDAL_USE_LERC_INTERNAL=ON \
  -DGDAL_USE_JPEG=ON \
  -DGDAL_USE_JPEG12_INTERNAL=OFF \
  -DGDAL_USE_JSONC=ON \
  -DGDAL_USE_KEA=ON \
%if %{with kml_support}
  -DGDAL_USE_LIBKML=ON \
%else
  -DGDAL_USE_LIBKML=OFF \
%endif
  -DGDAL_USE_LIBLZMA=ON \
  -DGDAL_USE_LIBXML2=ON \
  -DGDAL_USE_MYSQL=ON \
  -DGDAL_USE_NETCDF=ON \
  -DGDAL_USE_ODBC=ON \
  -DGDAL_USE_OGDI=OFF \
  -DGDAL_USE_OPENCL=ON \
  -DGDAL_USE_OPENJPEG=ON \
  -DGDAL_USE_PCRE2=ON \
  -DGDAL_USE_PNG=ON \
  -DGDAL_USE_POPPLER=ON \
  -DGDAL_USE_POSTGRESQL=ON \
%if %{with qhull_support}
  -DGDAL_USE_QHULL=ON \
%else
  -DGDAL_USE_QHULL=OFF \
%endif
%if %{with sfcgal_support}
  -DGDAL_USE_SFCGAL=ON \
%else
  -DGDAL_USE_SFCGAL=OFF \
%endif
  -DGDAL_USE_SHAPELIB=OFF \
  -DGDAL_USE_SPATIALITE=ON \
  -DGDAL_USE_TIFF=ON \
  -DGDAL_USE_WEBP=ON \
  -DGDAL_USE_XERCESC=ON \
  -DGDAL_USE_ZLIB=ON \
  -DGDAL_USE_ZSTD=ON \
  -DOGR_BUILD_OPTIONAL_DRIVERS=ON

%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{mypython_sitearch}
#remove duplicate license file
rm -f %{buildroot}%{_datadir}/%{name}/LICENSE.TXT

%if %{with tests_support}
%check
%ctest
pushd %{name}autotest-%{version}
	export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
	export GDAL_DATA=%{buildroot}%{_datadir}/%{name}/
    export PYTHONPATH=%{buildroot}%{mypython_sitearch}/
	export GDAL_DOWNLOAD_TEST_DATA=0
	# Enable these tests on demand
	#export GDAL_RUN_SLOW_TESTS=1

	# Some tests are currently skipped:
    # - `test_fits_vector` because it's crashing.
	# - `test_http*`, `test_jp2openjpeg_45`, `*multithreaded_download*`,
	#   `*multithreaded_upload*`, and `test_vsis3_no_sign_request`, which
	#   try to connect externally.
	# - `test_eedai_GOOGLE_APPLICATION_CREDENTIALS` which seems to use the
	#   internet.
	# - `test_osr_erm_1`, `test_ers_4`, `test_ers_8`, and `test_ers_10` as
	#   they use `ecw_cs.wkt` which was removed due to unclear license.
	# - `test_jpeg2000_8` and `test_jpeg2000_11` as files don't load,
	#   perhaps due to buggy Jasper library?
	# - `test_osr_ct_options_area_of_interest` returns the wrong value, but
	#   it's skipped on macOS by upstream for mysteriously failing as well,
	#   so do the same here.
	# - `test_ndf_1` because it hangs on i686 and armv7hl
# FIXME: Tests hang on i686 and armv7hl
%ifnarch i686 armv7hl
	pytest -k 'not test_fits_vector and not test_http and not test_jp2openjpeg_45 and not multithreaded_download and not multithreaded_upload and not test_vsis3_no_sign_request and not test_eedai_GOOGLE_APPLICATION_CREDENTIALS and not test_osr_erm_1 and not test_ers_4 and not test_ers_8 and not test_ers_10 and not test_jpeg2000_8 and not test_jpeg2000_11 and not test_osr_ct_options_area_of_interest and not test_ndf_1 and not test_cog_small_world_to_web_mercator and not test_bag and not gpkg and not jp2openjpeg and not wms and not heif' || :
%endif
popd
%endif

%ldconfig_scriptlets -n lib%{name}%{soversion}

%files -n lib%{name}%{soversion}
%license LICENSE.TXT
%{_libdir}/*.so.%{soversion}.*
%{_libdir}/*.so.%{soversion}

%files -n lib%{name}-drivers
%license LICENSE.TXT
%dir %{_libdir}/gdalplugins
%{_libdir}/gdalplugins/drivers.ini

%files
%license LICENSE.TXT
%doc NEWS.md PROVENANCE.TXT
%{_bindir}/gdal_contour
%{_bindir}/gdal_create
%{_bindir}/gdal_footprint
%{_bindir}/gdal_grid
%{_bindir}/gdal_rasterize
%{_bindir}/gdal_translate
%{_bindir}/gdal_viewshed
%{_bindir}/gdaladdo
%{_bindir}/gdalbuildvrt
%{_bindir}/gdaldem
%{_bindir}/gdalenhance
%{_bindir}/gdalinfo
%{_bindir}/gdallocationinfo
%{_bindir}/gdalmanage
%{_bindir}/gdalmdiminfo
%{_bindir}/gdalmdimtranslate
%{_bindir}/gdalsrsinfo
%{_bindir}/gdaltindex
%{_bindir}/gdaltransform
%{_bindir}/gdalwarp
%{_bindir}/gnmanalyse
%{_bindir}/gnmmanage
%{_bindir}/nearblack
%{_bindir}/ogr2ogr
%{_bindir}/ogrinfo
%{_bindir}/ogrlineref
%{_bindir}/ogrtindex
%{_bindir}/sozip
%{_datadir}/gdal
%{_mandir}/man1/gdal_contour.1%{?ext_man}
%{_mandir}/man1/gdal_create.1%{?ext_man}
%{_mandir}/man1/gdal_footprint.1%{?ext_man}
%{_mandir}/man1/gdal_rasterize.1%{?ext_man}
%{_mandir}/man1/gdal_translate.1%{?ext_man}
%{_mandir}/man1/gdal_viewshed.1%{?ext_man}
%{_mandir}/man1/gdaladdo.1%{?ext_man}
%{_mandir}/man1/gdalbuildvrt.1%{?ext_man}
%{_mandir}/man1/gdaldem.1%{?ext_man}
%{_mandir}/man1/gdalinfo.1%{?ext_man}
%{_mandir}/man1/gdallocationinfo.1%{?ext_man}
%{_mandir}/man1/gdalmanage.1%{?ext_man}
%{_mandir}/man1/gdalmdiminfo.1%{?ext_man}
%{_mandir}/man1/gdalmdimtranslate.1%{?ext_man}
%{_mandir}/man1/gdalsrsinfo.1%{?ext_man}
%{_mandir}/man1/gdaltindex.1%{?ext_man}
%{_mandir}/man1/gdaltransform.1%{?ext_man}
%{_mandir}/man1/gdalwarp.1%{?ext_man}
%{_mandir}/man1/gnmanalyse.1%{?ext_man}
%{_mandir}/man1/gnmmanage.1%{?ext_man}
%{_mandir}/man1/nearblack.1%{?ext_man}
%{_mandir}/man1/ogr2ogr.1%{?ext_man}
%{_mandir}/man1/ogrinfo.1%{?ext_man}
%{_mandir}/man1/ogrlineref.1%{?ext_man}
%{_mandir}/man1/ogrtindex.1%{?ext_man}
%{_mandir}/man1/sozip.1%{?ext_man}
# 20240706 with 3.9.x release we have all binaries in gdal
# and python311-GDAL contains the *.py equivalent.
%{_bindir}/gdalattachpct
%{_bindir}/gdal2tiles
%{_bindir}/gdal2xyz
%{_bindir}/gdal_calc
%{_bindir}/gdal_edit
%{_bindir}/gdal_fillnodata
%{_bindir}/gdal_merge
%{_bindir}/gdal_pansharpen
%{_bindir}/gdal_polygonize
%{_bindir}/gdal_proximity
%{_bindir}/gdal_retile
%{_bindir}/gdal_sieve
%{_bindir}/gdalcompare
%{_bindir}/gdalmove
%{_bindir}/ogrmerge
%{_bindir}/ogr_layer_algebra
%{_bindir}/pct2rgb
%{_bindir}/rgb2pct
%{_mandir}/man1/gdal2tiles.1%{?ext_man}
%{_mandir}/man1/gdal_calc.1%{?ext_man}
%{_mandir}/man1/gdal_edit.1%{?ext_man}
%{_mandir}/man1/gdal_fillnodata.1%{?ext_man}
%{_mandir}/man1/gdal_grid.1%{?ext_man}
%{_mandir}/man1/gdal_merge.1%{?ext_man}
%{_mandir}/man1/gdal_pansharpen.1%{?ext_man}
%{_mandir}/man1/gdal_polygonize.1%{?ext_man}
%{_mandir}/man1/gdal_proximity.1%{?ext_man}
%{_mandir}/man1/gdal_retile.1%{?ext_man}
%{_mandir}/man1/gdal_sieve.1%{?ext_man}
%{_mandir}/man1/gdalcompare.1%{?ext_man}
%{_mandir}/man1/gdalmove.1%{?ext_man}
%{_mandir}/man1/ogrmerge.1%{?ext_man}
%{_mandir}/man1/ogr_layer_algebra.1%{?ext_man}
%{_mandir}/man1/pct2rgb.1%{?ext_man}
%{_mandir}/man1/rgb2pct.1%{?ext_man}

%files devel
%license LICENSE.TXT
%doc NEWS.md PROVENANCE.TXT
%if %{with docs}
%doc doc/build/html/
%endif
%attr(755,root,root) %{_bindir}/gdal-config
%dir %{_libdir}/cmake/gdal
%{_libdir}/cmake/gdal/*.cmake
%{_libdir}/libgdal.so
%{_libdir}/pkgconfig/gdal.pc
%dir %{_includedir}/gdal
%{_includedir}/gdal/*.h
%{_mandir}/man1/gdal-config.1%{?ext_man}

%files -n %{mypython}-%{pypi_package_name}
%license LICENSE.TXT
%doc NEWS.md PROVENANCE.TXT
%{mypython_sitearch}/osgeo_utils
%{mypython_sitearch}/osgeo
%{mypython_sitearch}/GDAL-%{version}*-info
%{_bindir}/gdalattachpct.py
%{_bindir}/gdal2tiles.py
%{_bindir}/gdal2xyz.py
%{_bindir}/gdal_calc.py
%{_bindir}/gdal_edit.py
%{_bindir}/gdal_fillnodata.py
%{_bindir}/gdal_merge.py
%{_bindir}/gdal_pansharpen.py
%{_bindir}/gdal_polygonize.py
%{_bindir}/gdal_proximity.py
%{_bindir}/gdal_retile.py
%{_bindir}/gdal_sieve.py
%{_bindir}/gdalcompare.py
%{_bindir}/gdalmove.py
%{_bindir}/ogrmerge.py
%{_bindir}/ogr_layer_algebra.py
%{_bindir}/pct2rgb.py
%{_bindir}/rgb2pct.py

%files bash-completion
%license LICENSE.TXT
%{_datadir}/bash-completion/completions/*

%changelog
* Mon Apr  7 2025 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release version 3.10.3
  https://github.com/OSGeo/gdal/blob/v3.10.3/NEWS.md
  + Build
  - Fix build with -DWIN32_LEAN_AND_MEAN
  - Fix warnings when building against Poppler 25.03.00
  + Port
  - cpl_http: retry "SSL connection timeout"
  - /vsigs/ (and /vsiaz/): invalidate cached state of files/directories when
    changing authentication parameters (#11964)
  + Algorithms
  - Pansharpen: avoid I/O errors when extent of PAN and MS bands differ by
    less than the resolution of the MS band (#11889)
  - Warp: fix reprojecting on empty source window with nodata != 0 and MEM
    driver (#11992)
  + Utilities
  - gdaldem: allow -az zero or negative
  + Raster drivers
  - AVIF driver:
    remove limitation that prevented from reading images bigger than 10 MB
  - GRIB2 driver:
    fix reading Transverse Merctor with negative easting/falsing (#12015)
    also fix reading it with scale factor != 0.9996
  - GTiff driver:
    fix 3.10.1 regression when reading a file just created in multi-threaded
    mode with compression
  - MBTiles driver:
    fix update with WEBP compression
  - MRF driver:
    allow deflate expansion
  - PDF driver:
    fix default value for DPI open option description
  + OGR 3.10.3
  - Core
    SQLite dialect: make it compatible with SQLite 3.49.1 in SQLITE_DQS=0 mode
  - OGRSpatialReference
    ogrct.cpp: fix potential crash in multi-threaded execution (#11860)
  - Utilities
    ogr2ogr: fix -upsert with a GPKG source
  + Vector drivers
  - CSV driver:
    fix parsing of 64 bit integers above 2^53
  - GeoJSON driver:
    fix detection of features starting with {"geometry":{"type":"xxxxx",
    "coordinates":[... (qgis/QGIS#61266)
  - GMLAS driver:
    fix reading multiple values of a StringList field that is a repeated
    element (#12027)
  - GPKG driver:
    make it compatible with SQLite 3.49.1 in SQLITE_DQS=0 mode
    fix SetNextByIndex() followed by GetNextFeature() without explicit call
    to GetLayerDefn() (#11974)
  - MiraMonVector driver:
    fix error: Unexpected Non-nullptr Return
    fixing a word in Catalan language
    writing VRS in metadata file + error in the zMin, zMax values of the
    header
  - MSSQLSpatial driver:
    Fix creation of metadata tables related to "dbo"
  - OpenCAD driver:
    add missing std:: qualifiers
  - WFS driver:
    fix crash with GetFeatureCount() and client-side filters (#11920)
* Mon Mar 31 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libzstd-devel-static again: this was only a workaround to
  unblock Factory while waiting on the proper fix on zstd
  (boo#1240043).
* Thu Mar 27 2025 Andreas Stieger <andreas.stieger@gmx.de>
- fix build, need zstd-devel-static
- drop unneeded build dependencies on pcre, was ported to pcre2
* Sun Feb 16 2025 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release version 3.10.2
  https://github.com/OSGeo/gdal/blob/v3.10.2/NEWS.md
  [#]## Port
  * Fix read heap-buffer-overflow on nested /vsitar/ calls (ossfuzz
    [#388868487])
  * fix cppcheck nullPointerOutOfMemory
  [#]## Core
  * GDALGCPsToGeoTransform(): return FALSE when invalid
    geotransform is generated (#11618)
  [#]## Utilities
  * gdal_rasterize: Also accept doubles for -ts (#11829)
  [#]## Raster drivers
  [#]### PLMOSAIC driver:
  * Use a unique user-agent string to isolate usage of driver
  [#]### SNAP_TIFF driver:
  * third_party/libertiff: avoid issue with invalid offline tags
    with value offset at zero (ossfuzz #388571282)
  [#]### STACIT driver:
  * add STAC 1.1 support (#11753)
  * Identify(): accept if at least 2 of 'proj:transform',
    'proj:bbox' or 'proj:shape' are present
  [#]### WMS driver:
  * Update ESRI WMS links in documentation
- OGR 3.10.2
  [#]## Core
  * Fix GeodesicLength() that was quite severely broken as working
    only on closed linestrings (3.10.0 regression)
  [#]## Vector utilities
  * ogr2ogr: fix -clipsrc/-clipdst when a input geometry is within
    the envelope of a non-rectangle clip geometry, but doesn't
    intersect it (3.10.0 regression) (#11652, #10341)
  * ogrtindex: fix error message when specifying incorrect output
    driver
  * ogrlineref: make -f LIBKML to work without warning (#11719)
  [#]## Vector drivers
  [#]### CSV driver:
  * fix parsing files with double-quote inside a field value
    (#11660)
  [#]### DXF driver:
  * interpret INSERT blocks with row count or column count equal
    to 0 as 1 (#11591)
  [#]### Geoconcept driver:
  * fix potential double-free on creation error code
  [#]### GML driver:
  * gml:CircleByCenterPoint(): return a 5-point CIRCULARSTRING for
    compliance with ISO/IEC 13249-3:2011 (#11750)
  [#]### MiraMonVector driver:
  * Fix memory leak with oss-fuzz #393742177 scenario
  [#]### MVT driver:
  * allow generating tilesets with more than 1 tile at zoom level
    0 (#11749)
  * avoid infinite recursion on opening on hostile file (ossfuzz
    [#391974926])
  [#]### Parquet driver:
  * fix compiler deprecation warning with libarrow 19.0
  [#]# Python bindings
  * fix wrong comment in documentation (#11631)
  * on Debian, fix install target with non-Debian provided python
    version (#11636)
  * Avoid losing error message (#11795)
* Wed Jan 15 2025 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release version 3.10.1
  + CMake: FindDotnet.cmake: remove obsolete cmake_minimum_required()
  + CMake: fix swig/csharp/CMakeLists.txt compatibility with CMake 3.31
  + CMake: use add_compile_options() instead of setting CMAKE_CXX_FLAGS for -fno-finite-math-only (#11286)
  + Set GDAL_DEV_SUFFIX to the pre-release suffix if a corresponding Git tag was found.
  + PDF: fix build issue on CondaForge build infrastructure (gcc 13.3)
  + Fix issues in cpl_vsil_win32.cpp with latest mingw64
- Remove merged upstream 19ba2562.patch
* Sun Jan  5 2025 Bruno Friedmann <bruno@ioda-net.ch>
- Add upstream patch 19ba2562.patch to support newer poppler.
  fix boo#1235083
* Thu Nov  7 2024 Bruno Friedmann <bruno@ioda-net.ch>
- Update to feature release 3.10.0
  * https://github.com/OSGeo/gdal/blob/v3.10.0/NEWS.md
  * RFC 101: Raster dataset read-only thread-safety
  * New read/write AVIF raster driver
  * New read-only SNAP_TIFF raster driver for Sentinel Application
    Processing GeoTIFF files
  * New OGR read-only XODR driver for OpenDRIVE (#9504)
  * Code linting and security fixes
  * Bump of shared lib major version
* Sat Oct 26 2024 Enno Tensing <tenno+suse@suij.in>
- Update to release 3.9.3
  https://github.com/OSGeo/gdal/blob/v3.9.3/NEWS.md
* Sat Sep 28 2024 Ben Greiner <code@bnavigator.de>
- Fix SLE/Leap 15.6 build
  * Move to SLE/Leap python311 module: Old Python 3.6 is no longer
    supported by qgis
  * use gcc13-c++ (gcc7-c++ does not provide <charconv>)
  * Update build dependencies according to cmake defintions in
    order to make clear what is missing for SLE/Leap
* Mon Aug 26 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.9.1
  https://github.com/OSGeo/gdal/blob/v3.9.2/NEWS.md
  + Fix issue compiling with openssl 3.2.2 and libarchive 3.3.3
  + Fix -Wnull-dereference warnings of gcc 14.2
* Thu Jul  4 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.9.1
  https://github.com/OSGeo/gdal/blob/v3.9.1/NEWS.md
- update to version 3.9.0
  https://github.com/OSGeo/gdal/blob/v3.9.0/NEWS.md
  + fix boo#1227394 compilation error with libpoppler 24.06
- packaging: the following binaries are directly present in main gdal
  /usr/bin/gdal2tiles
  /usr/bin/gdal2xyz
  /usr/bin/gdal_calc
  /usr/bin/gdal_edit
  /usr/bin/gdal_fillnodata
  /usr/bin/gdal_merge
  /usr/bin/gdal_pansharpen
  /usr/bin/gdal_polygonize
  /usr/bin/gdal_proximity
  /usr/bin/gdal_retile
  /usr/bin/gdal_sieve
  /usr/bin/gdalattachpct
  /usr/bin/gdalcompare
  /usr/bin/gdalmove
  /usr/bin/ogr_layer_algebra
  /usr/bin/ogrmerge
  /usr/bin/pct2rgb
  /usr/bin/rgb2pct
  Their *.py equivalent are present in python3-GDAL, so we remove
  the hard dependency on python3-GDAL in gdal
  + remove duplicate LICENSE.TXT file in /usr/share/gdal
- spec cleaning
* Thu Apr  4 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.8.5 (last of 3.8 series)
  https://github.com/OSGeo/gdal/blob/v3.8.5/NEWS.md
* Mon Feb 26 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.8.4
  https://github.com/OSGeo/gdal/blob/v3.8.4/NEWS.md
* Tue Jan  9 2024 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.8.3
  https://github.com/OSGeo/gdal/blob/v3.8.3/NEWS.md
- Update copyright year
* Wed Dec 20 2023 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.8.2
  * Full list of changes in
  https://github.com/OSGeo/gdal/blob/v3.8.2/NEWS.md
* Tue Dec  5 2023 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release 3.8.1
  * Full list of changes in
  https://github.com/OSGeo/gdal/blob/v3.8.1/NEWS.md
- update to version 3.8.0
  * Full list of changes in
    https://github.com/OSGeo/gdal/blob/v3.8.0/NEWS.md
* Sun Nov 19 2023 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release version 3.7.3
  see https://github.com/OSGeo/gdal/blob/v3.7.3/NEWS.md
* Sun Oct  1 2023 Dirk Müller <dmueller@suse.com>
- update to 3.7.2:
  * GDAL 3.7.2 is a bugfix release.
  * /vsiaz/: fix cached URL names when listing /vsiaz/
  * /vsiaz/: add options to pass object_id/client_id/msi_res_id
    in IMDS
  * authentication requests (AZURE_IMDS_OBJECT_ID,
    AZURE_IMDS_CLIENT_ID,
  * AZURE_IMDS_MSI_RES_ID)
  * /vsiaz/: implement Azure Active Directory Workload Identity
    authentication,
  * typically for Azure Kubernetes
  * ### Core
  * TileMatrixSet::parse(): add support for OGC 2D Tile Matrix
    Set v2 (#6882)
  * Warper: do not modify bounds when doing
    geographic->geographic on a dataset
  * with world extent but not in [-180,180] (#8194)
  * RMS resampling: avoid potential integer overflow with UInt16
    values
  * GDALChecksumImage(): fix 3.6.0 regression regarding integer
    overflow on
  * images with more than 2 billion pixels (#8254)
  * gdalinfo -json output: emit a stac['proj:epsg'] = null object
    when emitting
  * proj:wkt2 or proj:projjson (#8137)
  * gdalmdimtranslate: fix wrong output dimension size when using
    syntax like
  * '-array name=XXX,view=[::factor_gt_1]'
  * gdal2tiles: fix exception with dataset in EPSG:4326 with
    longitudes > 180 in
  * WebMercator profile (#8100)
  * gdal_retile.py: allow gaps in input files larger than grid
    size (#8260)
  * GeoPackage driver:
  * GDALGeoPackageRasterBand::GetMetadata(): fix use after free
  * fix missing GRID_CELL_ENCODING metadata item when there is
    other metadata
  * remove .aux.xml file in Delete()
  * GTiff driver:
  * fix reading .tif + .tif.aux.xml file with xml:ESRI SourceGCPs
    without
  * TIFFTAG_RESOLUTIONUNIT (#8083)
  * HDF5 driver:
  * more efficient metadata collection (no functional change)
  * deal with int64/uint64 attributes
  * remove trailing space in multi-valued metadata items
  * remove dataset name prefix in band level metadata
  * address Planet's datacube band-specific metadata
  * NITF driver:
  * fix MIN/MAX_LONG/LAT when reading RPC00B
  * add support for CSCSDB (Common Sensor Covariance Support
    Data) DES from
  * GLAS/GFM SDEs
  * nitf_spec.xml: corrections to CSEXRB TRE
  * OGCAPI driver:
  * make it work when the media type of links (expected to be
    application/json)
  * is missing, using Accept content negotiation (#7970)
  * do not try to use the 'uri' member of a tilematrixset
    definition document
  * reproject bounding box from CRS84 to tile matrix set CRS
  * skip too small overview levels
  * remove erroneous taking into account of tilematrixset limits
  * STACIT driver:
  * correctly process asset 'href' starting with 'file://'
    (#8135)
  * make it tolerant to missing proj:epsg if proj:wkt2 or
    proj:projjson are
  * provided (#8137)
  * apply vsis3 protocol to s3:// items
  * WEBP driver:
  * fix build against libwebp < 0.4.0 (#8111)
  * Zarr driver:
  * Zarr V2: fix duplicate array listing when both a 'foo' file
    and 'foo/'
  * directory exist on the object storage (#8192)
* Mon Sep 25 2023 Dirk Stoecker <opensuse@dstoecker.de>
- Add Conflicts entry between drivers package and old library version
* Thu Sep 14 2023 Dirk Stoecker <opensuse@dstoecker.de>
- Seperate drivers.ini from the library package
* Mon Aug 21 2023 Bruno Friedmann <bruno@ioda-net.ch>
- update to bugfix release version 3.7.1
  * see https://github.com/OSGeo/gdal/blob/v3.7.1/NEWS.md
- update to feature release version 3.7.0
  + see https://github.com/OSGeo/gdal/blob/v3.7.0/NEWS.md
- packaging:
  * add new buildrequire pkgconfig(libarchive)
    for new /vsi7z/ and /vsirar/ virtual file systems
  * handle new delivered files
    data/gfs.xsd: XML schema for .gfs files (#6655)
    data/gml_registry.xsd: new file with XML schema of
    gml_registry.xml (#6716)
    data/ogrinfo_output.json.schema: validate ogrinfo -json output
    data/gdalinfo_output.schema.json: validate gdalinfo -json
    output (fixes #6850)
    data/grib2_table_4_2_0_21.csv
    data/grib2_table_4_2_2_6.csv
    bin/sozip
  * spec-cleaner
  * remove limitation for python < 3.11 as Factory has 3.11.4
* Fri May 26 2023 Boris Manojlovic <boris@steki.net>
- add required development rpms
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.6.3:
  * bugfixes
  * see https://github.com/OSGeo/gdal/blob/v3.6.3/NEWS.md
* Sun Jan  8 2023 Matthias Eliasson <elimat@opensuse.org>
- Update to version 3.6.2 bugfix release
  See changelog https://github.com/OSGeo/gdal/blob/v3.6.2/gdal/NEWS.md
* Thu Dec 15 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix 3.6.1 (critical)
  Important: GDAL 3.6.1 officially retracts GDAL 3.6.0
  which cause corruption of the spatial index of GeoPackage files
  it created (in tables with 100 000 features or more): cf
  https://github.com/qgis/QGIS/issues/51188 and
  https://github.com/OSGeo/gdal/pull/6911.
  GDAL 3.6.1 fixes that issue.
  Setting OGR_GPKG_ALLOW_THREADED_RTREE=NO environment variable
  (at generation time) also works around the issue with GDAL 3.6.0.
  Users who have generated corrupted GeoPackage files with 3.6.0
  can regnerate them with 3.6.1 with:
  "ogr2ogr out_ok.gpkg in_corrupted.gpkg"
  (assuming a GeoPackage file with vector content only)
  Consult the release notes for the list of issues addressed :
  https://github.com/OSGeo/gdal/blob/v3.6.1/NEWS.md
* Sat Nov 26 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Improve packaging
  + add proj for datum presence for tests
  + add cmake-full with tests_support (ctest)
  + add bison, shapelib,OpenEXR,armadillo,qhull,libz4,pcre2
    qhull,deflate are conditionnal(missing on Leap 15)
  + cmake force non use of internal, force use of external libs
    except lerc not packaged.
  + Exclude more tests (remote,out-of-memory)
* Fri Nov 25 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Set bash-completion as noarch
* Fri Nov 25 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.6.0:
  * https://github.com/OSGeo/gdal/blob/v3.6.0/gdal/NEWS.md
  * Fixes boo#1205745
- Skipped 3.5.0:
  * https://github.com/OSGeo/gdal/blob/v3.5.0/gdal/NEWS.md
  * Upstream dropped deprecated perl binding
  * Drop unneeded patch:
  - gdal-perl.patch
* Tue Mar 15 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.4.2 bugfix release
  See changelog https://github.com/OSGeo/gdal/blob/v3.4.2/gdal/NEWS.md
- Remove merged upstream patches gdal-fix-poppler-leap.patch
  and gdal-fix-build-poppler.patch
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gdal-fix-poppler-leap.patch: Fix build on Leap 15.4 and
  poppler.
- Add fdups macro, BuildRequires already in place, remove
  duplicate files.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gdal-fix-build-poppler.patch: Fix build with poppler 22.03.0
  and newer.
* Tue Jan  4 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Upgrade to version 3.4.1 bugfix release
  + Full changelog https://github.com/OSGeo/gdal/blob/v3.4.0/gdal/NEWS
  + Explicitly add a call to autogen.sh
  + Upstream PCIDSK: fix write heap-buffer-overflow boo#1194263
- Removed GDALmake.opt.in.patch due to cc1plus: warning:
  - I gcore: No such file or directory [-Wmissing-include-dirs]
- Add conditionnal support for hdf4 boo#1192614 on Leap
  build -with hdf4_support can be enabled
- Update copyright year
* Fri Dec 31 2021 D. Berge <opensuse@navlost.eu>
- Fix build on Leap 15.3
* Mon Nov 29 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Fix xerces detection by adding --with-xerces-inc parameter
* Mon Nov  1 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.3.3 bugfix release
  + Full changelog https://github.com/OSGeo/gdal/blob/v3.3.3/gdal/NEWS
- Removed upstream patches
  + gdal-poppler-2.10-a.patch
  + gdal-poppler-2.10-b.patch
* Wed Oct 20 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build with poppler 2.10:
  * gdal-poppler-2.10-a.patch
  * gdal-poppler-2.10-b.patch
* Tue Sep  7 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.3.2 bugfix release
  + Full changelog
    https://github.com/OSGeo/gdal/blob/v3.3.2/gdal/NEWS
* Sun Jul 11 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.3.1 bugfix release
  + Full changelog
    https://github.com/OSGeo/gdal/blob/v3.3.1/gdal/NEWS
* Mon May 24 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.3.0 version
  * Full changelog
    https://github.com/OSGeo/gdal/blob/v3.3.0/gdal/NEWS
  * Main changes python2 is now gone
- Packaging
  + bump libso version to 2.9
  + Remove python2 related stuff
  + Add support for heif,pcre,kml,sfcgal
    make conditionnal support of libkml, sfcgal, heif
  + Prepare tests also conditionnal
  + Several small cleanup (merged, no more)
  + Remove autoreconf upstream is using last available
* Mon May 17 2021 Dirk Müller <dmueller@suse.com>
- remove bundled libraries, use system provided ones
* Tue May  4 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.2.3 (bug fix release)
  * Full changelog
    https://github.com/OSGeo/gdal/blob/v3.2.3/gdal/NEWS
- Be warned about ahead changes with future 3.3.x version
    https://github.com/OSGeo/gdal/blob/v3.3.0/gdal/NEWS
* Fri Mar 12 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.2.2 (bug fix release):
  * Full changelog
    https://github.com/OSGeo/gdal/blob/v3.2.2/gdal/NEWS
* Mon Jan  4 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.2.1:
  * Full changelog
    https://github.com/OSGeo/gdal/blob/v3.2.1/gdal/NEWS
- Packaging:
  + Update copyright year
* Wed Nov  4 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.2.0:
  * Full changelog
    https://github.com/OSGeo/gdal/blob/v3.2.0/gdal/NEWS
- Packaging:
  + Add python3-GDAL as require in gdal package
  + Remove shebang where it's not allowed in python's scripts
* Sat Oct 24 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.1.4 version bug fix release see changelog
  https://github.com/OSGeo/gdal/blob/v3.1.4/gdal/NEWS
* Tue Sep  8 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.1.3 version bug fix release see changelog
  https://github.com/OSGeo/gdal/blob/v3.1.3/gdal/NEWS
* Sun Jul 19 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Work-around occasional build failures due to incomplete ordering
  in Makefile. (https://github.com/OSGeo/gdal/issues/2777)
- Avoid double gdal prefix for /usr/share/gdal/gdal/*
* Tue Jul  7 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.1.2 version bug fix release see changelog
  https://github.com/OSGeo/gdal/blob/v3.1.1/gdal/NEWS
* Tue Jun 30 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.1.1 version with full changelog
  https://github.com/OSGeo/gdal/blob/v3.1.1/gdal/NEWS
- Packaging:
  + drop merged upstream gdal-fix-docs.patch
  + Rework our way to deliver the package:
  - Remove building doc as we don't deliver it
  - Use upstream man page already present in tar
  - Simplify all %%if doc related stuff
  + Lower again a bit _constraints: 2.5G RAM 4.0G HDD
* Tue Jun 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid build failure
* Mon Jun 15 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix docs and man builds for Tumbleweed with upstream patch:
  * gdal-fix-docs.patch
- Disable docs/man on Leap - https://github.com/OSGeo/gdal/issues/2690
* Thu Jun 11 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.1.0:
  * New binaries: gdal_viewshed gdalmdiminfo gdalmdimtranslate
  * full changelog:
    https://github.com/OSGeo/gdal/blob/v3.1.0/gdal/NEWS
- Refresh patch:
  * GDALmake.opt.in.patch
- Drop upstream patches:
  * gdal-ecwjp2-sdk-5.5_dep1.patch
  * gdal-ecwjp2-sdk-5.5.patch
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without py2 available
* Fri Apr 17 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fixes for previous commit "Rework ECW5 SDK handling"
* Thu Apr  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Rework ECW5 SDK handling
- Fix build with ECW SDK 5.5 with upstream backports:
  * gdal-ecwjp2-sdk-5.5.patch
  * gdal-ecwjp2-sdk-5.5_dep1.patch
* Sat Feb  1 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 3.0.4 bugfix release
  + strongly recommended release for people creating GeoTIFF files
  in EPSG:3857 / WebMercator projection with previous 3x version
  + Changelog https://github.com/OSGeo/gdal/blob/v3.0.4/gdal/NEWS
* Wed Jan 22 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 3.0.3 bugfix release
  + Fix build with poppler 0.83 boo#1161399
  + Changelog https://github.com/OSGeo/gdal/blob/v3.0.3/gdal/NEWS
- Remove merged upstream patch
  0001-Replace-SWIG-Python-obj0-swig_obj-0-with-version-agn.patch
- refresh spec file with spec-cleaner
* Wed Nov  6 2019 Libor Pechacek <lpechacek@gmx.com>
- update to 3.0.2
  Full changelogs:
  https://trac.osgeo.org/gdal/wiki/Release/3.0.2-News
- Refreshed patches:
  0001-Replace-SWIG-Python-obj0-swig_obj-0-with-version-agn.patch
* Thu Oct 10 2019 Martin Pluskal <mpluskal@suse.com>
- Spec file cleanups
- Remove poppler boost dependnecy
- Enable LTO and zstd
* Sun Oct  6 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Fix build error on TW due to boo#1153146 poppler missing boost
  devel
* Thu Sep  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Swig 4.0, add
  0001-Replace-SWIG-Python-obj0-swig_obj-0-with-version-agn.patch
- Spec file cleanup, remove conditionals for Leap 42.x and older
* Mon Jul  8 2019 Dirk Stoecker <opensuse@dstoecker.de>
- update to 3.0.1
  Full changelogs:
  https://trac.osgeo.org/gdal/wiki/Release/3.0.1-News
  https://trac.osgeo.org/gdal/wiki/Release/3.0.0-News
  Patch pkg-config-libpq.patch included upstream
* Mon Jul  8 2019 Dirk Stoecker <opensuse@dstoecker.de>
- update to version 2.4.2
  Full changelog https://trac.osgeo.org/gdal/wiki/Release/2.4.2-News
* Thu Apr 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build with fgdb_support option enabled
* Thu Apr  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.4.1 (52 bugfix release)
  Full changelog https://trac.osgeo.org/gdal/wiki/Release/2.4.1-News
- Packaging:
  + Remove merged upstream patch
    add-support-for-poppler-0.72.0-and-0.73.0.patch
    Poppler-revision-version-management.patch
  + Add pkg-config-libpq.patch upstream issue#1412 pr#1418 wip
    use pkg-config for libpq
  + Secure libproj detection with tail -n1
* Thu Mar  7 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Fix boo#1128276 by providing correct Obsolete
* Sat Feb 23 2019 John Vandenberg <jayvdb@gmail.com>
- Use the Python package name 'GDAL' as used by upstream
* Wed Jan 30 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix build with the latest poppler in
  Tumbleweed:
  * Poppler-revision-version-management.patch
  * add-support-for-poppler-0.72.0-and-0.73.0.patch
* Mon Dec 24 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.4.0:
  * In a nutshell:
  - New GDAL drivers:
    ​BYN: read/write support for Natural Resources Canada's Geoid binary format
    ​EEDAI: read-only driver for Google Earth Engine Data API
    IGNFHeightASCIIGrid: read-only driver to read IGN-France height correction ASCII grids
    ​NGW: NextGIS Web read-only driver
    NTv1: read-only driver for NTv1 datum shift grids
  - New OGR drivers:
    ​EEDA: read-only driver for Google Earth Engine Data API
    ​GeoJSONSeq: read/creation support of new-line or record-separator separated GeoJSON features (#378)
    ​NGW: NextGIS Web read-write driver
  - Improved drivers:
    BAG: add read support for variable-resolution grids, and write support for single-resolution grids
    GTiff driver: add Lerc and WebP codecs
    PostgisRaster?: add support for out-db rasters
    RMF
    MSSQLSpatial
  - RFC 72: Make GDAL Python autotest suite use pytest framework
  - Add /vsihdfs/ virtual file system handler for Hadoop File System (via libhdfs)
  - Add /vsiwebhdfs/ read-write virtual file system for Web Hadoop File System REST API
  - gdal_contour rewriting: speed optimizations and capability to compute polygon isosurfaces.
  - Remove PHP and Ruby bindings.
  - Continued code linting in C++, Python scripts, Shell scripts and autotest
  * Backward compatibility issues
  - The value of COMPRESSION_ZSTD used for ZStd-in-TIFF compression has been changed.
    ZStd-compressed TIFF files produced by GDAL 2.3.0 will not be readable
  * Full changelog: https://trac.osgeo.org/gdal/wiki/Release/2.4.0-News
- Add md5 checksum
- Refresh patch:
  * gdal-perl.patch
* Mon Dec 24 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.3.3: Bugfix
  See details https://trac.osgeo.org/gdal/wiki/Release/2.3.3-News
* Sat Sep 29 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to new bugfix 2.3.2 version
  See details https://trac.osgeo.org/gdal/wiki/Release/2.3.2-News
  This adds 65 bug fixes on top of 2.3.1.
  The C and C++ API and ABI are unchanged.
- Packaging:
  + spec-cleaner -m -i URL and Requires order changes
  + Remove patch gdal-fix_ecw5_detection.patch (merged upstream)
  + Redone patch GDALmake.opt.in.patch with version 2.3.2
* Tue Jul 31 2018 bruno@ioda-net.ch
- Remove patch gdal-libproj.patch, we can't have hardcoded libproj
  soversion. Replaced by dynamic sed formula.
  Fix boo#1102889
* Fri Jul 27 2018 guillaume.gardet@opensuse.org
- Fix FileGDB support
* Tue Jul 17 2018 guillaume.gardet@opensuse.org
- Add patch to fix ECW5 detection in configure:
  * gdal-fix_ecw5_detection.patch
* Tue Jul 10 2018 guillaume@opensuse.org
- Enable KEA support
* Fri Jul  6 2018 bruno@ioda-net.ch
- Upgrade to new bugfix 2.3.1 version
  See details https://trac.osgeo.org/gdal/wiki/Release/2.3.0-News
  + Fix build with recent Poppler (0.64) (#573)
  + PDF driver: fix build against PDFium (#612)
  + Do not use json-c private API RDA and AmigoCloud? drivers(#618)
  + fix build against MySQL 8.0
  + Include gdalsse_priv.h from user defined paths
  + Unix:
  - update GRASS drivers to support GRASS 7.4.0 (#633)
  - configure: use CXXFLAGS when CXX is used (#693)
- Packaging : redone patches against new version
  + gdal-perl.patch
* Thu Jun 14 2018 guillaume.gardet@opensuse.org
- Add optional filegdb_api support, disabled by default
* Fri Jun  1 2018 opensuse@dstoecker.de
- require libopenjp2 for devel package
* Mon May 14 2018 bruno@ioda-net.ch
- Upgrade to new 2.3.0 version
  See details https://trac.osgeo.org/gdal/wiki/Release/2.3.0-News
  + Source code is now hosted on github
  + RFC 70: Guessing output format from output file name extension
    for utilities
    https://trac.osgeo.org/gdal/wiki/rfc70_output_format_guess
  + RFC 68: C++11 Compilation requirement
    https://trac.osgeo.org/gdal/wiki/rfc68_cplusplus11
    GDAL now requires a C++11 compatible compiler. External code
    using GDAL C++ API will also need to enable at least C++11
    compilation mode, if the compiler defaults to C++98/C++03.
  + Stricter const-ness in OGRGeomFieldDefn, OGRFeatureDefn and
    OGRFeature classes, impacting out-of-tree drivers that subclass
    them.
- Packaging : redone patches against new version
  + GDALmake.opt.in.patch
  + gdal-libproj.patch
* Mon May  7 2018 guillaume.gardet@opensuse.org
- Add optional support to ECW5 JPEG lib support disabled by default
* Thu Apr  5 2018 bruno@ioda-net.ch
- Fix boo#1088014 by adding missing LICENSE in lib and main package
  Remove misplaced LICENSE.txt in /usr/share/gdal
* Thu Mar 22 2018 bruno@ioda-net.ch
- Update to new upstream bugfix release 2.2.4
  See details https://trac.osgeo.org/gdal/wiki/Release/2.2.4-News
- Remove merged patch gdal-json-c-0.13.patch
- Maximize usage of pkgconfig
* Fri Jan 12 2018 dimstar@opensuse.org
- Replace poppler-devel BuildRequires with pkgconfig(poppler): the
  name 'poppler-devel' was last used in openSUSE 11.4. By using the
  pkgconfig() symbol, we don't have to care for actual package
  names.
- Add gdal-json-c-0.13.patch: Fix build with json-c 0.13.
* Thu Nov 23 2017 bruno@ioda-net.ch
- Update to new upstream bugfix release 2.2.3
  See details https://trac.osgeo.org/gdal/wiki/Release/2.2.3-News
- Packaging :
  + remove wrong /usr/bin/env python shebang
  + use /usr/bin/python3 for all /usr/bin/gdal*.py scripts
- Remove gdal-2.2.2-mariadb_102_build_fix.patch merged upstream
* Wed Nov  8 2017 kstreitova@suse.com
- add gdal-2.2.2-mariadb_102_build_fix.patch to fix build with
  MariaDB 10.2 (in our case the build with libmariadb library
  from the mariadb-connector-c package)
  * upstream commit d63c1a90f81fc3c1f58a8742fb68baf81340ea03)
* Sat Sep 23 2017 bruno@ioda-net.ch
- New upstream bugfix release 2.2.2
  See details https://trac.osgeo.org/gdal/wiki/Release/2.2.2-News
* Tue Aug  1 2017 tchvatal@suse.com
- Drop the php5 dependency. The php7 bindings are not ready and we
  are removing php5
* Fri Jul 14 2017 toddrme2178@gmail.com
- Add python2-gdal provides for the python-gdal subpackage for
  compatibility with single-spec python macros.
* Wed Jul 12 2017 bruno@ioda-net.ch
- New upstream bugfix release 2.2.1
  See details https://trac.osgeo.org/gdal/wiki/Release/2.2.1-News
- Packaging
  + Remove gdal-upstream-issue#6898-changeset#38636.patch merged
* Wed May 24 2017 bruno@ioda-net.ch
- New upstream release 2.2.0
  - https://trac.osgeo.org/gdal/wiki/Release/2.2.0-News
- Packaging
  + add patch gdal-upstream-issue#6898-changeset#38636.patch
    fixing non void return garbage in swig/perl.
  + redone patches against 2.2.0
    gdal-libproj.patch
    GDALmake.opt.in.patch
    gdal-perl.patch
* Fri Feb  3 2017 Angelos Tzotsos <tzotsos@opensuse.org>
- New upstream bugfix release 2.1.3
  - https://trac.osgeo.org/gdal/wiki/Release/2.1.3-News
* Sat Oct 29 2016 bruno@ioda-net.ch
- Due to build failure on non x86 arch, and advise from upstream
  comment out the usage of obsolete jasper.
  We have openjpeg2 anyway.
* Fri Oct 28 2016 bruno@ioda-net.ch
- New upstream bugfix release 2.1.2
  - https://trac.osgeo.org/gdal/wiki/Release/2.1.2-News
- Packaging changes
  - remove netcdf-gcp-fix.patch (uptream)
* Mon Oct 17 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Packaging changes
  - Fixed gdal-libproj.patch to point to libproj.so.12
* Fri Sep 30 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- Packaging changes
  - Added netcdf-gcp-fix.patch from upstream (#6666)
* Sun Sep 25 2016 bruno@ioda-net.ch
- New upstream bugfix release 2.1.1
  - https://trac.osgeo.org/gdal/wiki/Release/2.1.1-News
- Packaging changes
  - Remove ogr_wrap.patch included upstream
  - Added support to liblzma
* Tue May 10 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- New upstream release 2.1.0
  - https://trac.osgeo.org/gdal/wiki/Release/2.1.0-News
- packaging changes
  - Removed gdal-python_install.patch
  - Removed gdal-2.0.2-sqlite-crash.patch
  - Removed gdal-configure.patch
  - Added ogr_wrap.patch to solve no-return-in-non-void-function error
  - Submitted ogr_wrap.patch upstream: https://trac.osgeo.org/gdal/ticket/6506
  - Redone patch GDALmake.opt.in.patch
* Tue Feb 23 2016 bruno@ioda-net.ch
- Upgrade to 2x series version : 2.0.2 bugfix release
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.2-News
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.1-News
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.0-News
- packaging
  - Redone patch GDALmake.opt.in.patch and gdal-libproj.patch
  - Delete upstream merged gdal-python-swig3-issue6045.path
  - Delete upstream merged gdal_swig-perl-issue3084.patch
  - Add gdal-2.0.2-sqlite-crash.patch Fix upstream issue 6360
  - spec-cleaner minimal (pkgconfig make unresolvable all except
    Leap and Tumbleweed)
* Thu Feb  4 2016 behrisch@users.sourceforge.net
- Fixing PACKAGE_* redefines in cpl_config.h
* Sun Jan 31 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- New upstream patch release 1.11.4
* Wed Dec  9 2015 mpluskal@suse.com
- Enable opencl and freexl support
- Update dependencies
* Fri Sep 25 2015 ecsos@opensuse.org
- Upgrade to version 1.11.3
  see http://trac.osgeo.org/gdal/wiki/Release/1.11.3-News
- remove following patches, because their are now in source:
  - gdal-poppler-0.31.patch
  - gdal-python-swig3-issue6045.patch
  - gdal-gcc5-getaddrinfo-issue6073.patch
* Fri Aug 28 2015 bruno@ioda-net.ch
- packaging
  Redone exclusion for <= 1310 and 1315
  Cleanup empty perl bs files
- Build fixes
  * Fix python coding in swig3+ (backport of gdal20)
  with patch gdal-python-swig3-issue6045.patch
  * Fix gcc5 build upstream issue 6073
  gdal-gcc5-getaddrinfo-issue6073.patch
* Wed Aug 26 2015 bruno@ioda-net.ch
- Adding python3 support
- move fdupes from buildroot (mix python scripts otherwise)
  fdupes is run against source html directory
- dos2unix Fix EOL warnings
* Sat Jul  4 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Fix build to use libproj9
* Fri May 29 2015 guillaume@opensuse.org
- Fix ECW detection in configure script (need to add -pthread to CFLAGS)
* Sat May  2 2015 ecsos@opensuse.org
- Upgrade to version 1.11.2
  * Build
  - configure: fix detection of OCI by changing linking order
    to please modern GCC (#5550)
  - configure: fix test to accept MariaDB 10.X as valid MySQL
    (#5722)
  - More compiler warnings addressed (#5414)
  - Windows build of PDF: fix compilation issue with
    Visual Studio 2012 (#5744)
  - Windows build: Add support for MrSID 9.1 SDK (#5814)
  - Windows build: when building netCDF, HDF4, HDF5 as plugins,
    call registration of 'sub-drivers' GMT, HDF4Image and
    HDF5Image (#5802)
  * Port
  - CSV finder: Stop probing for csv/horiz_cs.csv. (#5698)
  - /vsicurl/: avoid reading after end-of-file and fix failure
    when reading more than 16MB in a single time (#5786)
  - CPLHexToBinary(): faster implementation (#5812)
  * GDAL Core and algorithms
  - Make GetMaskBand?() work with GDT_UInt16 alpha bands (#5692)
  - Fix 32bit overflow in GDALRasterBand::IRasterIO() (#5713)
  - RPC transformer: take into account nodata in RPC DEM (#5680)
  - RPC transformer: add RPC_DEM_MISSING_VALUE transformer option
    to avoid failure when there's no DEM at the transformed point
    (#5730)
  - Fix GDALSuggestedWarpOutput() wrong extent in some
    circumstances (e.g. dataset of big dimension with world
    coordinates) (#5693)
  - Fix crash when calling GetTiledVirtualMem?() on non-Linux
    platform (#5728)
  - warp: fix integer overflow when reprojecting into an area
    with (part of) bounds completely outside of the source
    projection (#5789)
  - OpenCL warper: fix OpenCL code compilation with NVIDIA OpenCL
    (#5772)
  * Utilities
  - gdalwarp: initialize destination dataset to no_data value
    when automatically propagating source nodata (#5675)
  - gdalwarp: only apply INIT_DEST when processing the first
    input dataset (#5387)
  - gdaldem: avoid too large files to be produced when using
  - co COMPRESS=xxxx -co TILED=YES (#5678)
  * GDAL drivers
  - GRASS driver:
  - fix compilation issues against GRASS 7 (#2953)
  - GIF driver:
  - fix crash on images without color table (#5792)
  - validate the size of the graphic control extension block
  (#5793)
  - GTiff driver:
  - Internal overviews: for near, average, gauss, and pixel
  interleaving, make sure to use the same code path for
  compressed vs uncompressed overviews (#5701)
  - allow lossless copying of CMYK JPEG into JPEG-in-TIFF
  (#5712)
  - when overriding metadata in update mode, make sure to clear
  it from PAM file (#5807)
  - fix GTiffRasterBand::DirectIO() to work with TIFF files
  with multiple directories (overviews, masks) (#5831)
  - Internal libtiff: partial (mostly security related fixes)
  upgrade to 4.0.4beta (#5830)
  - ISIS3 driver:
  - fix to recognize IsisCube?.Mapping.LatitudeType? =
  Planetocentric (#5717)
  - JP2OpenJPEG driver:
  - add compatibility with OpenJPEG 2.1 (#5579)
  - JPEG driver:
  - Report non-fatal libjpeg errors as CE_Warning
  (or CE_Failure if GDAL_ERROR_ON_LIBJPEG_WARNING = TRUE)
  (#5667)
  - KMLSuperOverlay driver:
  - remove useless and unreliable computations on floating
  point numbers that caused issues (truncated raster)
  on 32bit (#5683)
  - USGSDEM driver:
  - take into account horizontal unit = ft in the UTM case
  (#5819)
  - VRT driver:
  - fix RasterIO() to be able to fill buffers larger than 2GB
  (#5700, #5734)
  * OGR core
  - ogr_core.h: only ignore -Wfloat-equal for IsInit?() and not
    for the rest of the file and files that inc it (#5299)
  - OGR layer algebra: properly initialize field maps to avoid
    Valgrind warnings in OGRLayer::Update() (#5778)
  * OGR drivers
  - CSV driver:
  - fix segfault when reading allCountries.txt of geonames.org
  (#5668)
  - FileGDB:
  - avoid emitting error when opening a FileGDB v9, so that
  OpenFileGDB can be tried to open it, in the case FileGDB
  is a plugin (#5674)
  - GeoJSON driver:
  - ESRIJson: parse correctly rings of esriGeometryPolygon
  objects to build correct Polygon or MultiPolygon? (#5538)
  - GML driver:
  - Fix incorrect geometry cast when reading GML topogeometries
  (#5715)
  - Update GFS files for RUIAN (UVOH & OB) (#5770)
  - LIBKML driver:
  - when skipped, fix segfault on second OGRRegisterAll() call
  (#5775)
  - do not delete the libkml singleton factory (linked to #5775)
  - MapInfo? File driver:
  - Add GDA94 datum entries to the lookup table (#5671)
  - fix segfault in CreateFeature?() if passing an invalid OGR
  feature style string (#1209)
  - MSSQL driver:
  - Fix recognizing image columns as geometry columns for the
  select layers. (#5498)
  - Fix issue when creating non-spatial table (#5696)
  - Fix to read metadata if the tables are specified in the
  connection string (#5796)
  - Fix invalid use of CSLAddString() in OGR MSSQL (#5810)
  - Fix crash if the tablename is specified in the connection
  string (#5826)
  - MySQL driver:
  - don't be dependant on locale when building spatial filter
  (#5720)
  - NAS driver:
  - make chevrons configurable by NAS_INDICATOR (#5708)
  - OCI driver:
  - Initialize member variable to avoid UpdateLayerExtents?()
  to be called randomly on non spatial tables (#5376)
  - fix FID (multi_load=off, OGRNullFID) - start with 1
  (not -1) (#5454)
  - OpenFileGDB driver:
  - fix ResetReading?() on SQL layer with ORDER BY on indexed
  column (#5669)
  - add support for non spatial GDB v9 tables (#5673)
  - PG driver:
  - fix GDAL 1.11.0 regression that prevented to retrieve more
  than 500 features from a connection with tables= parameter
  and on a SQL result layer (#5837)
  - SQLite/Spatialite driver:
  - remove 'T' suffix when formatting the content of a Date
  field (#5672)
  - fix segmentation fault when executing OGR2SQLITE_Register()
  when compiling against sqlite 3.8.7 (#5725)
  - make GetFIDColumn() work when run as first method call
    (#5781)
  - VRT driver:
  - do not propagate ignoring of x and y cols of a
  PointFromColumns? to the source layer (#5777)
  - XLSX driver:
  - fix column numbering when there are more than 26 columns
  (#5774)
  * SWIG Language Bindings
  - Python bindings:
  - Fix hang of Python in case of repeated call to gdal/ogr.
  UseExceptions?() and CE_Warning emitted (#5704)
  - fix processing error of ogr_python.i with SWIG 3 (#5795)
  - NUMPY driver: avoid returning CE_None in GetGeoTransform?()
  when there's no geotransform set (#5801)
* Fri Mar 27 2015 dimstar@opensuse.org
- Add gdal-poppler-0.31.patch: Fix build with poppler 0.31+.
* Tue Mar 10 2015 schubert.seb@gmail.com
- Fix hard coded proj4 library name
  * gdal-libproj.patch
* Sun Mar  8 2015 mpluskal@suse.com
- Update perl package dependencies
* Mon Feb  9 2015 mpluskal@suse.com
- Add GDALmake.opt.in.patch to fix random failures of parallel
  builds
* Mon Feb  9 2015 mpluskal@suse.com
- Build with hdf5 on suse recent suse releases.
- Correct license and bundle license with packages.
- Misc spec file cleanups.
- Build with webp support if possible.
- Use autoreconf when possible to avoid issues with improper
  cflags used and parallel builds.
- Rename package to match upstream name (gdal) - library is
  provided as libgdal1 which matches shared libraries policy.
* Tue Dec 16 2014 guillaume@opensuse.org
- Add optional support to ECW JPEG lib support (disabled by default)
* Sat Oct 11 2014 behrisch@users.sourceforge.net
- fixing build with older autotools (SLE11SP3, CentOS6)
- removing obsolete patch
* Thu Oct  2 2014 ecsos@schirra.net
  Upgrade to version 1.11.1
- Build
  * Fix compilation errors with json-c 0.12 (#5449)
  * configure: fix for cpl_recode_iconv.cpp compilation error
    on freebsd 10 (#5452)
  * Fix compilation error in alg/gdalgrid.cpp when AVX is available,
    but not SSE (#5566)
  * Fix wrong include order in ingr and nitf subdirs w.r.t internal
    libtiff (#5644)
  * Add CPL_UNUSED for gcc >= 4 (#5414)
- Port
  * CPLSpawn() on Windows: quote arguments with spaces
    in them (#5469)
  * /vsigzip/: avoid infinite loop when reading broken
    .gml.gz file (#5486)
  * /vsizip/: fix bug that caused premature end of file condition
    with some read patterns (#5530)
  * /vsizip/: on >4GB zips: accept .zip declare 0 disks (#5615)
  * Fix stack corruption upon thread termination with
    CPLSetThreadLocalConfigOption on Windows 32 bit (#5590,
    reported by cleo)
  * cpl_http.cpp: truly set CURLOPT_NOSIGNAL if available (#5568)
- GDAL Core
  * EXIF reader: add missing validation for some data types (#3078)
  * Fix segfault in GDALPamRasterBand::SerializeToXML() when
    saving an empty RAT (#5451)
  * Windows plugin: complementary fix to #5211 to avoid error
    dialog box when there are dependency problems (#5525)
  * RPC transformer with DEM: fix near interpolation
    (patch by liminlu0314, #5553)
  * OpenCL warper: remove unused variable in bilinear resampling
    that can cause compilation error (#5518)
  * GDALCreateTPSTransformer(): fix crash if the forward or backward
    transform cannot be computed (#5588)
  * Overview: ignore alpha=0 values when compute an average overview
    of an alpha band; and also avoid memory errors when calling
    GetMaskBand?()/GetMaskFlags() after overview computation if
    GetMaskXXX() has been called before (#5640)
- Utilities
  * gdal2tiles.py: fix inverted long/lat in BoundingBox? and
    Origin elements of tilemapresource.xml (#5336)
  * pct2rgb.py: make it work (again) with color tables with
    less than 256 entries (#5555)
  Previous upgrades from version 1.11.0
- New GDAL drivers:
  * KRO: read/write support for KRO KOKOR Raw format
- New OGR drivers:
  * CartoDB : read/write support
  * GME (Google Map Engine) : read/write support
  * GPKG (GeoPackage): read-write support (vector part of the spec.)
  * OpenFileGDB: read-only support (no external dependency)
  * SXF: read-only support
  * WALK : read-only support
  * WAsP .map : read-write support
- Significantly improved drivers: GML, LIBKML
- RFC 40: enhanced RAT support (#5129)
- RFC 41: multiple geometry fields support
- RFC 42: OGR Layer laundered field lookup
- RFC 43: add GDALMajorObject::GetMetadataDomainList?() (#5275)
- RFC 45: GDAL datasets and raster bands as virtual memory mapping
- Upgrade to EPSG 8.2 database
* Thu Oct  3 2013 Angelos Tzotsos <tzotsos@opensuse.org>
  Upgrade to version 1.10.1:
- Compilation fixes for iOS (#5197, #5198)
- Fix VSISubFileHandle::Eof() behaviour to be POSIX compliant, so that the shapefile reader can read the last feature when using /vsitar (#5093)
- vsicache: fix for 32bit binaries when file size is over 2GB (#5170)
- warper: Fix warping when input pixel size is too close to 0 (#5190)
- GDALFillNodata(): Fix use of uninitialized memory and integer overflows (#4010, #5203)
- Fix ref-counting of callable passed to gdal.PushErrorHandler?() (#5186)
* Mon Jun  3 2013 dvaleev@suse.com
- install man to the %%{_mandir}
* Sat May 25 2013 behrisch@users.sourceforge.net
- removing dox from RHEL and derivatives
* Thu May 23 2013 behrisch@users.sourceforge.net
- added dependency to libltdl for the devel package
* Wed May  8 2013 behrisch@users.sourceforge.net
- Added openjpeg2 to the devel requirements
* Mon Apr 29 2013 Angelos Tzotsos <tzotsos@opensuse.org>
  Upgrade to version 1.10 final:
  * New GDAL drivers:
  - ARG: read/write suuport for ARG datasets (#4591)
  - CTable2: read/write support for CTable2 datum grid shift format
  - DDS: write-only support for DirectDraw? Surface format (#5017)
  - IRIS: read support for products generated by the IRIS weather radar software (#4854)
  - MAP: read OziExplorer? .map files (#3380)
  - MBTiles: read-only support for MBTiles rasters (needs libsqlite3)
  * New OGR drivers:
  - ElasticSearch?: write-only support to write into ElasticSearch? databases (needs libcurl)
  - ODS : read/write support for OpenOffice? .ods (Open Document Spreadsheets) (needs libexpat)
  - OSM : read-only support for .osm / .pbf OpenStreetMap? files
  - PDF: read/write support for vector/structured PDF files
  - XLSX: read/write support for MS Excel 2007 and later Open Office XML .xlsx spreadsheets (needs libexpat)
  * RFC 39: OGR Layer algebra methods : http://trac.osgeo.org/gdal/wiki/rfc39_ogr_layer_algebra
  * Add a SQL SQLite dialect :  http://gdal.org/ogr/ogr_sql_sqlite.html
  * Make GDAL loadable as a SQLite3 extension (named VirtualOGR) (#4782)
  * /vsicurl_streaming/: new virtual file system handler designed to read in streaming mode dynamically generated files
  * GDAL API_PROXY mechanism to run GDAL drivers in a separate process:  http://gdal.org/gdal_api_proxy.html
  * Significantly improved drivers : PDF, SQLite, JP2OpenJPEG
  * Add a geocoding client :  http://gdal.org/ogr/ogr__geocoding_8h.html
  * Upgrade to EPSG 8.0 database
* Thu Apr 18 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC3
* Sun Apr 14 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC2
* Sun Apr 14 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC1
* Mon Apr  8 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Restored OpenJPEG2000 dependency
- Upgraded to version 1.10beta2
* Tue Dec  4 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Removed hardcoded Requires
* Sun Nov 25 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Disabled OpenJPEG support until we have a patch for OpenJPEG 2.0 final
* Sun Oct 14 2012 schwab@linux-m68k.org
- gdal-postgisraster-array-overflow.patch
  PostGISRaster: fix array overflow
* Fri Oct 12 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to new release 1.9.2:
    Fix infinite GDALOpen recursion with some VRTs (#4835)
    Avoid destroying existing overviews (.aux/.rrd) (#4831)
    Support recognising NaN better in !CPLStrtod() (#4799)
    Fix windows declaration for !CPLGetErrorHandlerUserData() (#4755)
    Fix compilation with Gentoo modified zlib 1.2.6 (#4723)
    Look for libgeotiff headers in /usr/include/libgeotiff too (#4706)
    Improve warning handling in !CPLClearRecodeStubWarningFlags() (#4650)
    Fix Solaris compilation bug (#4705)
    !MorphFromESRI(): compare SPHEROID/PRIMEM parms, not names (#4673)
* Thu Sep 27 2012 behrisch@users.sourceforge.net
- fixing sles dependencies
* Wed Sep 26 2012 behrisch@users.sourceforge.net
- fixing sles 10 build by not regenerating swig files
* Wed Sep 19 2012 behrisch@users.sourceforge.net
- fixed ScientificLinux dependencies
* Fri Sep 14 2012 behrisch@users.sourceforge.net
- Fixed CentOS 6 and ScientificLinux 6 build
- Fixed SLE build
* Fri Jun 29 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- added new parameters to avoid issue:
    https://bugs.archlinux.org/task/30471
    http://www.mail-archive.com/ubuntu@lists.osgeo.org/msg00330.html
* Fri Jun 15 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Fixed Factory build
- Added poppler patch from branch 1.9
- Added libgeotiff include path patch (now upstream too)
* Fri Jun  1 2012 kukuk@suse.de
- remove obsolete doxygen patch
* Thu May 31 2012 kukuk@suse.de
- Fix libXerces-c dependency for SLES
* Wed May 23 2012 tzotsos@opensuse.org
- Update to new release 1.9.1
  * fix crash with VSICachedFile::Read() for large reads (#4646)
  * Unix VSI*L: correctly set current offset after a failed read (#4583)
  * Improve OpenJDK finding logic in configure. (#4643)
  * Fix iconv configure problem on FreeBSD (#4525)
  * Fix MinGW build when pthread is also available (#4430)
  * makegdalXX.vcproj : update 71,80 and 90 version. Drop 10 version --> open the 90 version and VS2010 should convert it (#4415)
  * reverseWindingOrder(): don't force coordinate dimension to 3 (#4621)
  * Fix incorrect rounding in OGRFormatDouble (#4614)
  * Fix segfault when running 'ogr2ogr target src -select AFIELD -where FID=xxx' when the source layer has more than 5 fields (#4500)
- gdal-sqlite.patch moved upstream http://trac.osgeo.org/gdal/ticket/4515
* Sat May 12 2012 behrisch@users.sourceforge.net
- fixed scientific linux build
- moved to external libgeotiff which works better with QLandkarteGT
* Wed Apr  4 2012 behrisch@users.sf.net
- fixed RHEL6 (and derivatives) build
* Wed Feb 15 2012 dassau@gbd-consult.de
- added gdal-sqlite.patch to fix http://trac.osgeo.org/gdal/ticket/4515
* Tue Jan 10 2012 dassau@gbd-consult.de
- Update to new release 1.9.0
  * New GDAL drivers: ACE2, CTG, E00GRID, ECRGTOC, GRASSASCIIGrid,
    GTA, NGSGEOID, SNODAS, WebP, ZMap
  * New OGR drivers:  ARCGEN, CouchDB, DWG, EDIGEO, ESRI FileGDB, Geomedia,
    Google Fusion Tables, IDRISI, MDB, SEGUKOOA, SEGY, SVG, XLS
  * Significantly improved drivers: NetCDF
  * Encoding support for shapefile/dbf (#882)
  * RFC 35: Delete, reorder and alter field definitions of OGR layers
  * RFC 37: Add mechanism to provide user data to CPLErrorHandler (#4295)
  * gdalsrsinfo: new supported utility to report SRS in various form
    (supercedes testepsg)
* Thu Jul 21 2011 dassau@gbd-consult.de
- Update to new release 1.8.1
* Wed Apr 27 2011 dassau@gbd-consult.de
- Added curl as dependency to support (wms/wcs/...)
* Sun Apr 24 2011 toddrme2178@gmail.com
- Switched to valid groups (fix for RPMLINT warning)
* Thu Apr 14 2011 behrisch@users.sourceforge.net
- fix CentOS and SLE10 build
* Sat Apr  9 2011 hpj@urpla.net
- fix python dependencies and build, clean up spec
* Mon Jan 24 2011 dassau@gbd-consult.de
- update to new version
  Sat Nov 13 00:00:00 UTC 2010 - Otto Dassau 1.7.3
- update to new version with many small fixes and changes
  Thu Jun 24 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- added soname patch for building without libtool
  Wed Apr 14 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- added perl and python packages with help from fedora spec by Balint Cristian
  Thu Feb 11 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- update to new version
  Mon Nov 30 00:00:00 UTC 2009 - Otto Dassau 1.6.3
- update to new version
  Tue Nov 24 00:00:00 UTC 2009 - Otto Dassau 1.6.2
- update to new version
  Mon May 18 00:00:00 UTC 2009 - Otto Dassau 1.6.1
- update to new version
  Wed Feb 18 00:00:00 UTC 2009 - Otto Dassau 1.6.0
- update to new version
- adapted hdf4 patch
- removed ogpython and enabled current python bindings
  Thu Dec  4 00:00:00 UTC 2008 - Otto Dassau 1.5.3
- new patch to prevent getting upside-down images with NetCDF (ticket 2654)
  Tue Oct 21 00:00:00 UTC 2008 - Otto Dassau 1.5.3
- update to new version
  Thu Jun 12 00:00:00 UTC 2008 - Otto Dassau 1.5.2
- update to new bugfix version and added hdf4 support
  Sun Mar 23 00:00:00 UTC 2008 - Otto Dassau 1.5.1
- update to new version
  Mon Dec 31 00:00:00 UTC 2007 - Otto Dassau 1.5.0
- added with-ogpython
- BuildRequires: +unixODBC-devel, +libgeos-devel
- added more tools
  Thu Dec 20 00:00:00 UTC 2007 - Otto Dassau 1.4.4
- update to 1.4.4 and added mysql support
  Mon Aug 13 00:00:00 UTC 2007 - Dirk Stoecker 1.4.2
- adapted for openSUSE BuildService
  Mon Jul 16 00:00:00 UTC 2007 - Otto Dassau 1.4.2
- first built
  Mon Jun 11 00:00:00 UTC 2007 - Otto Dassau 1.4.1
- first built
  Tue Dec 19 00:00:00 UTC 2006 - Otto Dassau 1.3.2
- built on SuSE 10.2
  Mon Jun 19 00:00:00 UTC 2006 - Markus Neteler 1.3.2
- added DB support; gdal_rasterize
  Wed Jan 25 00:00:00 UTC 2006 - Otto Dassau 1.3.1
- adapted to SuSE 10.0
